package main

import (
	"flag"
	"fmt"
	"net/http"

	"git.ramonr.ch/ramon/mediaconverter/converter"
	"k8s.io/klog"
)

const iTunesDir = "/mnt/data/media/iTunes/iTunes Media/Automatically Add to Music.localized"

// set at compile time
var (
	version = ""
	commit  = ""
)

func main() {
	klog.InitFlags(nil)
	listenAddr := flag.String("listen-addr", "127.0.0.1:8088", "the address where to listen on")
	flag.Parse()
	fmt.Printf("Mediaconverter version %v, commit %v\n", version, commit)

	http.HandleFunc("/", conversionHandler())
	fmt.Println("Starting to listen on", *listenAddr)
	err := http.ListenAndServe(*listenAddr, nil)
	fmt.Println(err)
}

func conversionHandler() http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		if err := converter.New(iTunesDir).Process(r.Body); err != nil {
			klog.Errorf("could not convert: %v", err)
			fmt.Fprintf(w, "could not convert: %v", err)
		}
	}
}
